@@ -7,7 +7,7 @@ SEXP copyEnv(SEXP e1, SEXP e2, SEXP all);
 SEXP listToEnv(SEXP, SEXP);
 SEXP listLen(SEXP);
 SEXP rowQ(SEXP, SEXP);
-SEXP rowMedians(SEXP, SEXP, SEXP);
+SEXP rowMedians(SEXP, SEXP, SEXP, SEXP);
 SEXP rowQuantiles(SEXP, SEXP);
 SEXP unsafe_set_slot(SEXP obj, SEXP slot, SEXP value);
 SEXP lc_prefix(SEXP, SEXP);
@@ -24,7 +24,7 @@ __declspec(dllexport)
         {"listToEnv", (DL_FUNC)&listToEnv, 2},
         {"listLen", (DL_FUNC)&listLen, 1},
         {"rowQ", (DL_FUNC)&rowQ, 2},
-        {"rowMedians", (DL_FUNC)&rowMedians, 3},
+        {"rowMedians", (DL_FUNC)&rowMedians, 4},
         {"unsafe_set_slot", (DL_FUNC)&unsafe_set_slot, 3},
         {"lc_prefix", (DL_FUNC)&lc_prefix, 2},
         {"sublist_extract", (DL_FUNC)&sublist_extract, 4},
